samsung_pay_listener library

Classes

AddCardListener
The requested add card operation status is returned via this listener.
CardInfoListener
This listener is for listening requestCardInfo() callback events.
CustomSheetTransactionInfoListener
This interface is for listening callback events of online (in-app) custom sheet payment. This is invoked when card is changed by the user on the custom payment sheet, and also with the success or failure of online (in-app) payment.
GetCardListener
The requested getAllCards operation status is returned via this listener.
SheetUpdatedListener
This listener is for listening SheetControl events.
StatusListener
The requested operation status is returned via this listener. Upon on success, status and extra data (if any) will be returned via onSuccess callback. On any failure, the error code and error reason is provided along with failure callback.