samsung_pay_sdk_flutter
library
Classes
-
AddCardInfo
-
This class provides card information for enrollment.
-
AddCardListener
-
The requested add card operation status is returned via this listener.
-
Address
-
Address object managed by UserInfoCollection returned when calling API
-
AddressControl
-
This class provides AddressControl on custom payment sheet.
-
AmountBoxControl
-
This class provides AmountBoxControl on custom payment sheet.
AmountBoxControl is used for displaying amount information on custom payment sheet.
-
CardInfo
-
This class provides card information such as card brand.
Supported card brands are as follows:
-
CardInfoListener
-
This listener is for listening requestCardInfo() callback events.
-
CustomSheet
-
This class provides custom payment sheet which contains various SheetControls.
-
CustomSheetPaymentInfo
-
This class provides APIs to fetch Payment information details with custom payment sheet information.
That is, transaction details set by the merchant app.
-
CustomSheetTransactionInfoListener
-
This interface is for listening callback events of online (in-app) custom sheet payment.
This is invoked when card is changed by the user on the custom payment sheet,
and also with the success or failure of online (in-app) payment.
-
GetCardListener
-
The requested getAllCards operation status is returned via this listener.
-
MethodChannelSamsungPaySdkFlutter
-
An implementation of SamsungPaySdkFlutterPlatform that uses method channels.
-
PartnerInfo
-
This class holds the partner information.
Any third party application using the Samsung Pay SDK is considered as partner app.
The third party application can be an issuer app (bank app), merchant app, and so on.
-
PaymentCardInfo
-
This class provides card information related to payment operations.
-
PlainTextControl
-
This class provides PlainTextControl on custom payment sheet.
This control is used for displaying 2-line text with title or 1-line text without title.
-
SamsungPaySdkFlutter
-
This class provides APIs to get the Samsung Pay status on the device.
-
SamsungPaySdkFlutterPlatform
-
-
SheetControl
-
This class is basic class for each component on custom payment sheet.
-
SheetItem
-
This class provides basic data APIs for SheetControl
-
SheetUpdatedListener
-
This listener is for listening SheetControl events.
-
SpaySdk
-
This class allows to define Samsung Pay SDK information, common error codes, and constants.
-
SpinnerControl
-
This class provides SpinnerControl on custom payment sheet.
SpinnerControl is used for displaying spinner option on custom payment sheet.
-
StatusListener
-
The requested operation status is returned via this listener.
Upon on success, status and extra data (if any) will be returned via onSuccess callback.
On any failure, the error code and error reason is provided along with failure callback.
-
WalletCard
-
This class provides card information related to the card management operations.
Enums
-
AddressInPaymentSheet
-
This enumeration provides types of address UI on the payment sheet, based on merchant requirement.
-
Brand
-
This enumeration provides SDK supported card brands such as
AMERICAN EXPRESS, MASTERCARD, VISA, DISCOVER, CHINA UNIONPAY, OCTOPUS, ECI and PAGOBANCOMAT.
-
Controltype
-
This enumeration provides SDK supported SheetControl type such as
PLAINTEXT, AMOUNTBOX, ADDRESS and SPINNER.
-
ServiceType
-
This enumeration provides Service Types.
Partners must set their Service Type in the PartnerInfo when they call any APIs.
-
SheetItemType
-
This enumeration provides SDK supported SheetControl type such as
PLAINTEXT, AMOUNTBOX, ADDRESS and SPINNER.